pub struct Ptr<T: ?Sized = ()> { /* private fields */ }Expand description
Typed virtual address.
Implementations
Sourceimpl<T: ?Sized> Ptr<T>
impl<T: ?Sized> Ptr<T>
Sourcepub const fn cast<U: ?Sized>(self) -> Ptr<U>
pub const fn cast<U: ?Sized>(self) -> Ptr<U>
Casts the pointer to a different type keeping the pointer address fixed.
Sourcepub const fn offset<U: ?Sized>(self, offset: i64) -> Ptr<U>
pub const fn offset<U: ?Sized>(self, offset: i64) -> Ptr<U>
Offsets and casts the pointer.
Because the type of the current and the target may be unrelated, this is a byte offset.
Examples
use pelite::pe64::Ptr;
#[repr(C)]
struct Composite {
int: i32,
float: f32,
}
let p: Ptr<Composite> = Ptr::from(0x2000);
let target = p.offset::<f32>(4);
assert_eq!(target, Ptr::from(0x2004));Trait Implementations
Sourceimpl<T: ?Sized> Ord for Ptr<T>
impl<T: ?Sized> Ord for Ptr<T>
Sourceimpl<T: ?Sized> PartialOrd for Ptr<T>
impl<T: ?Sized> PartialOrd for Ptr<T>
impl<T: ?Sized> Copy for Ptr<T>
impl<T: ?Sized> Eq for Ptr<T>
impl<T: ?Sized> Pod for Ptr<T>where
Ptr<T>: 'static,